@@ -603,7 +603,7 @@ static void
 about(void)
 {
 	printf("%s %s\n", PACKAGE_NAME, PACKAGE_VERSION);
-	printf("Copyright (c) 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020\n");
+	printf("Copyright (c) 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020, 2021\n");
 	printf("    pkgconf authors (see AUTHORS in documentation directory).\n\n");
 	printf("Permission to use, copy, modify, and/or distribute this software for any\n");
 	printf("purpose with or without fee is hereby granted, provided that the above\n");
@@ -1015,6 +1015,9 @@ main(int argc, char *argv[])
 		return EXIT_SUCCESS;
 	}
 
+	if (getenv("PKG_CONFIG_FDO_SYSROOT_RULES"))
+		want_client_flags |= PKGCONF_PKG_PKGF_FDO_SYSROOT_RULES;
+
 	if ((want_flags & PKG_SHORT_ERRORS) == PKG_SHORT_ERRORS)
 		want_client_flags |= PKGCONF_PKG_PKGF_SIMPLIFY_ERRORS;
 
@@ -1040,7 +1043,7 @@ main(int argc, char *argv[])
 	 * this allows for a --static which searches private modules, but has the same fragment behaviour as if
 	 * --static were disabled.  see <https://github.com/pkgconf/pkgconf/issues/83> for rationale.
 	 */
-	if ((want_flags & PKG_PURE) == PKG_PURE || getenv("PKG_CONFIG_PURE_DEPGRAPH") != NULL)
+	if ((want_flags & PKG_PURE) == PKG_PURE || getenv("PKG_CONFIG_PURE_DEPGRAPH") != NULL || personality->want_default_pure)
 		want_client_flags &= ~PKGCONF_PKG_PKGF_MERGE_PRIVATE_FRAGMENTS;
 
 	if ((want_flags & PKG_ENV_ONLY) == PKG_ENV_ONLY)
@@ -1062,7 +1065,7 @@ main(int argc, char *argv[])
 	if ((want_flags & PKG_NO_PROVIDES) == PKG_NO_PROVIDES)
 		want_client_flags |= PKGCONF_PKG_PKGF_SKIP_PROVIDES;
 
-	if ((want_flags & PKG_DONT_DEFINE_PREFIX) == PKG_DONT_DEFINE_PREFIX)
+	if ((want_flags & PKG_DONT_DEFINE_PREFIX) == PKG_DONT_DEFINE_PREFIX  || getenv("PKG_CONFIG_DONT_DEFINE_PREFIX") != NULL)
 		want_client_flags &= ~PKGCONF_PKG_PKGF_REDEFINE_PREFIX;
 
 	if ((want_flags & PKG_INTERNAL_CFLAGS) == PKG_INTERNAL_CFLAGS)
@@ -1101,8 +1104,18 @@ main(int argc, char *argv[])
 		pkgconf_client_set_buildroot_dir(&pkg_client, builddir);
 
 	if ((sysroot_dir = getenv("PKG_CONFIG_SYSROOT_DIR")) != NULL)
+	{
+		const char *destdir;
+
 		pkgconf_client_set_sysroot_dir(&pkg_client, sysroot_dir);
 
+		if ((destdir = getenv("DESTDIR")) != NULL)
+		{
+			if (!strcmp(destdir, sysroot_dir))
+				want_client_flags |= PKGCONF_PKG_PKGF_FDO_SYSROOT_RULES;
+		}
+	}
+
 	/* we have determined what features we want most likely.  in some cases, we override later. */
 	pkgconf_client_set_flags(&pkg_client, want_client_flags);
 
